@@ -14,7 +14,11 @@ import warnings
 from pyiron_base.state import state
 from pyiron_base.jobs.job.extension.executable import Executable
 from pyiron_base.jobs.job.extension.jobstatus import JobStatus
-from pyiron_base.jobs.job.core import JobCore
+from pyiron_base.jobs.job.core import (
+    JobCore,
+    _doc_str_job_core_args,
+    _doc_str_job_core_attr,
+)
 from pyiron_base.jobs.job.runfunction import (
     run_job_with_parameter_repair,
     run_job_with_status_initialized,
@@ -65,68 +69,11 @@ intercepted_signals = [
 ]  # , signal.SIGQUIT]
 
 
-class GenericJob(JobCore):
-    """
-    Generic Job class extends the JobCore class with all the functionality to run the job object. From this class
-    all specific Hamiltonians are derived. Therefore it should contain the properties/routines common to all jobs.
-    The functions in this module should be as generic as possible.
-
-    Sub classes that need to add special behavior after :method:`.copy_to()` can override
-    :method:`._after_generic_copy_to()`.
-
-    Args:
-        project (ProjectHDFio): ProjectHDFio instance which points to the HDF5 file the job is stored in
-        job_name (str): name of the job, which has to be unique within the project
-
-    Attributes:
-
-        .. attribute:: job_name
-
-            name of the job, which has to be unique within the project
-
-        .. attribute:: status
-
-            execution status of the job, can be one of the following [initialized, appended, created, submitted,
-                                                                      running, aborted, collect, suspended, refresh,
-                                                                      busy, finished]
-
-        .. attribute:: job_id
-
-            unique id to identify the job in the pyiron database
-
-        .. attribute:: parent_id
-
-            job id of the predecessor job - the job which was executed before the current one in the current job series
-
-        .. attribute:: master_id
-
-            job id of the master job - a meta job which groups a series of jobs, which are executed either in parallel
-            or in serial.
-
-        .. attribute:: child_ids
-
-            list of child job ids - only meta jobs have child jobs - jobs which list the meta job as their master
-
-        .. attribute:: project
-
-            Project instance the jobs is located in
-
-        .. attribute:: project_hdf5
-
-            ProjectHDFio instance which points to the HDF5 file the job is stored in
-
-        .. attribute:: job_info_str
-
-            short string to describe the job by it is job_name and job ID - mainly used for logging
-
-        .. attribute:: working_directory
-
-            working directory of the job is executed in - outside the HDF5 file
-
-        .. attribute:: path
-
-            path to the job as a combination of absolute file system path and path within the HDF5 file.
-
+# Modular Docstrings
+_doc_str_generic_job_attr = (
+    _doc_str_job_core_attr
+    + "\n"
+    + """\
         .. attribute:: version
 
             Version of the hamiltonian, which is also the version of the executable unless a custom executable is used.
@@ -168,7 +115,25 @@ class GenericJob(JobCore):
 
             Job type object with all the available job types: ['ExampleJob', 'SerialMaster', 'ParallelMaster',
                                                                'ScriptJob', 'ListMaster']
-    """
+"""
+)
+
+
+class GenericJob(JobCore):
+    __doc__ = (
+        """
+    Generic Job class extends the JobCore class with all the functionality to run the job object. From this class
+    all specific Hamiltonians are derived. Therefore it should contain the properties/routines common to all jobs.
+    The functions in this module should be as generic as possible.
+
+    Sub classes that need to add special behavior after :method:`.copy_to()` can override
+    :method:`._after_generic_copy_to()`.
+"""
+        + "\n"
+        + _doc_str_job_core_args
+        + "\n"
+        + _doc_str_generic_job_attr
+    )
 
     def __init__(self, project, job_name):
         super(GenericJob, self).__init__(project, job_name)
@@ -1306,7 +1271,7 @@ class GenericJob(JobCore):
 
     def set_input_to_read_only(self):
         """
-        This function enforces read-only mode for the input classes, but it has to be implement in the individual
+        This function enforces read-only mode for the input classes, but it has to be implemented in the individual
         classes.
         """
         pass
