@@ -7,8 +7,14 @@ The GenericMaster is the template class for all meta jobs
 
 import inspect
 import textwrap
+from functools import wraps
+from typing import Union
 
-from pyiron_base.jobs.job.generic import GenericJob
+from pyiron_base.storage.parameters import GenericParameters
+from pyiron_base.storage.datacontainer import DataContainer
+from pyiron_base.interfaces.object import HasStorage
+from pyiron_base.jobs.job.core import _doc_str_job_core_args
+from pyiron_base.jobs.job.generic import GenericJob, _doc_str_generic_job_attr
 from pyiron_base.jobs.job.extension.jobstatus import job_status_finished_lst
 from pyiron_base.jobs.job.jobtype import JobType
 
@@ -24,109 +30,39 @@ __status__ = "production"
 __date__ = "Sep 1, 2017"
 
 
-class GenericMaster(GenericJob):
-    """
-    The GenericMaster is the template class for all meta jobs - meaning all jobs which contain multiple other jobs. It
-    defines the shared functionality of the different kind of job series.
-
-    Args:
-        project (ProjectHDFio): ProjectHDFio instance which points to the HDF5 file the job is stored in
-        job_name (str): name of the job, which has to be unique within the project
-
-    Attributes:
-
-        .. attribute:: job_name
-
-            name of the job, which has to be unique within the project
-
-        .. attribute:: status
-
-            execution status of the job, can be one of the following [initialized, appended, created, submitted,
-                                                                      running, aborted, collect, suspended, refresh,
-                                                                      busy, finished]
-
-        .. attribute:: job_id
-
-            unique id to identify the job in the pyiron database
-
-        .. attribute:: parent_id
-
-            job id of the predecessor job - the job which was executed before the current one in the current job series
-
-        .. attribute:: master_id
-
-            job id of the master job - a meta job which groups a series of jobs, which are executed either in parallel
-            or in serial.
-
-        .. attribute:: child_ids
-
-            list of child job ids - only meta jobs have child jobs - jobs which list the meta job as their master
-
-        .. attribute:: project
-
-            Project instance the jobs is located in
-
-        .. attribute:: project_hdf5
-
-            ProjectHDFio instance which points to the HDF5 file the job is stored in
-
-        .. attribute:: job_info_str
-
-            short string to describe the job by it is job_name and job ID - mainly used for logging
-
-        .. attribute:: working_directory
-
-            working directory of the job is executed in - outside the HDF5 file
-
-        .. attribute:: path
-
-            path to the job as a combination of absolute file system path and path within the HDF5 file.
-
-        .. attribute:: version
-
-            Version of the hamiltonian, which is also the version of the executable unless a custom executable is used.
-
-        .. attribute:: executable
-
-            Executable used to run the job - usually the path to an external executable.
-
-        .. attribute:: library_activated
-
-            For job types which offer a Python library pyiron can use the python library instead of an external
-            executable.
-
-        .. attribute:: server
-
-            Server object to handle the execution environment for the job.
-
-        .. attribute:: queue_id
-
-            the ID returned from the queuing system - it is most likely not the same as the job ID.
-
-        .. attribute:: logger
-
-            logger object to monitor the external execution and internal pyiron warnings.
-
-        .. attribute:: restart_file_list
-
-            list of files which are used to restart the calculation from these files.
-
-        .. attribute:: job_type
-
-            Job type object with all the available job types: ['ExampleJob', 'SerialMaster', 'ParallelMaster',
-                                                               'ScriptJob', 'ListMaster']
-
+# Modular Docstrings
+_doc_str_generic_master_attr = (
+    _doc_str_generic_job_attr
+    + "\n"
+    + """\
         .. attribute:: child_names
 
             Dictionary matching the child ID to the child job name.
-    """
+"""
+)
+
+
+class GenericMaster(GenericJob):
+    __doc__ = (
+        """
+    The GenericMaster is the template class for all meta jobs - meaning all jobs which contain multiple other jobs. It
+    defines the shared functionality of the different kind of job series.
+
+"""
+        + "\n"
+        + _doc_str_job_core_args
+        + "\n"
+        + _doc_str_generic_master_attr
+    )
 
     def __init__(self, project, job_name):
         super(GenericMaster, self).__init__(project, job_name=job_name)
+        self._input = GenericParameters("parameters")
         self._job_name_lst = []
         self._job_object_dict = {}
         self._child_id_func = None
         self._child_id_func_str = None
+        self._python_only_job = True
 
     @property
     def child_names(self):
@@ -136,10 +72,10 @@ class GenericMaster(GenericJob):
         Returns:
             dict: {child_id: child job name }
         """
-        child_dict = {}
-        for child_id in self.child_ids:
-            child_dict[child_id] = self.project.db.get_item_by_id(child_id)["job"]
-        return child_dict
+        return {
+            child_id: self.project.db.get_item_by_id(child_id)["job"]
+            for child_id in self.child_ids
+        }
 
     @property
     def child_ids(self):
@@ -164,6 +100,19 @@ class GenericMaster(GenericJob):
         else:
             return self.project.open(self.job_name + "_hdf5")
 
+    @property
+    def input(self):
+        return self._input
+
+    @input.setter
+    def input(self, new_input: Union[DataContainer, GenericParameters, HasStorage]):
+        if isinstance(new_input, (DataContainer, GenericParameters, HasStorage)):
+            self._input = new_input
+        else:
+            raise TypeError(
+                f"Expected a DataContainer, GenericParameters or HasStorage object but got {new_input.__class__}"
+            )
+
     def child_hdf(self, job_name):
         """
         Find correct HDF for new children.  Depending on `self.server.new_hdf` this creates a new hdf file or creates
@@ -193,6 +142,10 @@ class GenericMaster(GenericJob):
         """
         return self._job_object_dict
 
+    @wraps(GenericJob.set_input_to_read_only)
+    def set_input_to_read_only(self):
+        self._input.read_only = True
+
     def first_child_name(self):
         """
         Get the name of the first child job
@@ -295,6 +248,7 @@ class GenericMaster(GenericJob):
         """
         super(GenericMaster, self).to_hdf(hdf=hdf, group_name=group_name)
         with self.project_hdf5.open("input") as hdf5_input:
+            self.input.to_hdf(hdf5_input)
             hdf5_input["job_list"] = self._job_name_lst
             self._to_hdf_child_function(hdf=hdf5_input)
         for job in self._job_object_dict.values():
@@ -310,6 +264,7 @@ class GenericMaster(GenericJob):
         """
         super(GenericMaster, self).from_hdf(hdf=hdf, group_name=group_name)
         with self.project_hdf5.open("input") as hdf5_input:
+            self.input.from_hdf(hdf5_input)
             job_list_tmp = hdf5_input["job_list"]
             self._from_hdf_child_function(hdf=hdf5_input)
             self._job_name_lst = job_list_tmp
@@ -372,7 +327,8 @@ class GenericMaster(GenericJob):
             for child_id in self.child_ids
         ]
         if isinstance(item, int):
-            item = self._job_name_lst[item]
+            total_lst = self._job_name_lst + child_name_lst
+            item = total_lst[item]
         return self._get_item_when_str(
             item=item, child_id_lst=child_id_lst, child_name_lst=child_name_lst
         )
