@@ -8,7 +8,8 @@ The ListMaster behaves like a list, just for job objects.
 from pyiron_base.storage.parameters import GenericParameters
 from pyiron_base.jobs.job.core import JobCore
 from pyiron_base.jobs.job.generic import GenericJob
-from pyiron_base.jobs.master.generic import GenericMaster
+from pyiron_base.jobs.job.core import _doc_str_job_core_args
+from pyiron_base.jobs.master.generic import GenericMaster, _doc_str_generic_master_attr
 from pyiron_base.jobs.master.submissionstatus import SubmissionStatus
 from pyiron_base.jobs.job.jobtype import JobType
 
@@ -24,124 +25,39 @@ __status__ = "production"
 __date__ = "Sep 1, 2017"
 
 
+# Modular Docstrings
+_doc_str_list_master_attr = (
+    _doc_str_generic_master_attr
+    + "\n"
+    + """\
+        .. attribute:: submission_status
+
+            Monitors how many jobs have been submitted and how many have to be submitted in future
+"""
+)
+
+
 class ListMaster(GenericMaster):
-    """
+    __doc__ = (
+        """
     The ListMaster is the most simple MetaJob derived from the GenericMaster. It behaves like a Python list object. Jobs
     can be append to the ListMaster just like elements are added to a list and then all jobs can be executed together.
     This also works for already executed jobs, unless they are already linked to a different MetaJob - meaning they
     already have a master ID assigned to them.
-
-    Args:
-        project (ProjectHDFio): ProjectHDFio instance which points to the HDF5 file the job is stored in
-        job_name (str): name of the job, which has to be unique within the project
-
-    Attributes:
-
-        .. attribute:: job_name
-
-            name of the job, which has to be unique within the project
-
-        .. attribute:: status
-
-            execution status of the job, can be one of the following [initialized, appended, created, submitted,
-                                                                      running, aborted, collect, suspended, refresh,
-                                                                      busy, finished]
-
-        .. attribute:: job_id
-
-            unique id to identify the job in the pyiron database
-
-        .. attribute:: parent_id
-
-            job id of the predecessor job - the job which was executed before the current one in the current job series
-
-        .. attribute:: master_id
-
-            job id of the master job - a meta job which groups a series of jobs, which are executed either in parallel
-            or in serial.
-
-        .. attribute:: child_ids
-
-            list of child job ids - only meta jobs have child jobs - jobs which list the meta job as their master
-
-        .. attribute:: project
-
-            Project instance the jobs is located in
-
-        .. attribute:: project_hdf5
-
-            ProjectHDFio instance which points to the HDF5 file the job is stored in
-
-        .. attribute:: job_info_str
-
-            short string to describe the job by it is job_name and job ID - mainly used for logging
-
-        .. attribute:: working_directory
-
-            working directory of the job is executed in - outside the HDF5 file
-
-        .. attribute:: path
-
-            path to the job as a combination of absolute file system path and path within the HDF5 file.
-
-        .. attribute:: version
-
-            Version of the hamiltonian, which is also the version of the executable unless a custom executable is used.
-
-        .. attribute:: executable
-
-            Executable used to run the job - usually the path to an external executable.
-
-        .. attribute:: library_activated
-
-            For job types which offer a Python library pyiron can use the python library instead of an external
-            executable.
-
-        .. attribute:: server
-
-            Server object to handle the execution environment for the job.
-
-        .. attribute:: queue_id
-
-            the ID returned from the queuing system - it is most likely not the same as the job ID.
-
-        .. attribute:: logger
-
-            logger object to monitor the external execution and internal pyiron warnings.
-
-        .. attribute:: restart_file_list
-
-            list of files which are used to restart the calculation from these files.
-
-        .. attribute:: job_type
-
-            Job type object with all the available job types: ['ExampleJob', 'SerialMaster', 'ParallelMaster',
-                                                               'ScriptJob', 'ListMaster']
-
-        .. attribute:: child_names
-
-            Dictionary matching the child ID to the child job name.
-
-        .. attribute:: submission_status
-
-            Monitors how many jobs have been submitted and how many have to be submitted in future.
-    """
+"""
+        + "\n"
+        + _doc_str_job_core_args
+        + "\n"
+        + _doc_str_list_master_attr
+    )
 
     def __init__(self, project, job_name):
-        self._input = GenericParameters("parameters")
         super(ListMaster, self).__init__(project, job_name=job_name)
         self.__version__ = "0.1"
         self._input["mode"] = "parallel"
         self.submission_status = SubmissionStatus(db=project.db, job_id=self.job_id)
         self.refresh_submission_status()
 
-    def set_input_to_read_only(self):
-        """
-        This function enforces read-only mode for the input classes, but it has to be implement in the individual
-        classes.
-        """
-        self._input.read_only = True
-
     def reset_job_id(self, job_id=None):
         """
         Reset the job id sets the job_id to None as well as all connected modules like JobStatus and SubmissionStatus.
@@ -276,14 +192,6 @@ class ListMaster(GenericMaster):
         ):
             self.status.finished = True
 
-    def write_input(self):
-        """
-        Write the input files - for the ListMaster this only contains the execution mode, which is 'parallel' by
-        default.
-        """
-        super().write_input()
-        self._input.write_file(file_name="input.inp", cwd=self.working_directory)
-
     def copy(self):
         """
         Copy the ListMaster object which links to the job and its HDF5 file
@@ -340,28 +248,6 @@ class ListMaster(GenericMaster):
         """
         pass
 
-    def __getitem__(self, item):
-        """
-        Get/ read data from the HDF5 file
-
-        Args:
-            item (str, slice): path to the data or key of the data object
-
-        Returns:
-            dict, list, float, int: data or data object
-        """
-        child_id_lst = self.child_ids
-        child_name_lst = [
-            self.project.db.get_item_by_id(child_id)["job"]
-            for child_id in self.child_ids
-        ]
-        if isinstance(item, int):
-            total_lst = child_name_lst + self._job_name_lst
-            item = total_lst[item]
-        return self._get_item_when_str(
-            item=item, child_id_lst=child_id_lst, child_name_lst=child_name_lst
-        )
-
     def __len__(self):
         """
         Length of the ListMaster equal the number of childs appended.
